-- main.lua
-- ****** Comment *****************************************************
-- Revision: 1.0
-- Issued  : mar.15, 2025
-- Auther  : Tanzai
-- Contents: This script controlls a plugin, "F1M2_fittings" in FiM2 Zerokan 4.0
--           for X-Plane 12. 
-- Notice 1: This script may be redistributed for non commercial purposes
--           only; derivatives MAY NOT be redistributed.
-- *******************************************************************

setAircraftPanelRendering(false)
set3DRendering(false)
setInteractivity(true)

addSearchResourcesPath ( moduleDirectory .. "/configuration/" )
local sim_time = globalPropertyf("sim/operation/misc/frame_rate_period")
local rollHold = findCommand ( "sim/autopilot/wing_leveler" )
local gearUp = findCommand ( "sim/flight_controls/landing_gear_up" )
local headX = globalPropertyf("sim/graphics/view/pilots_head_x")                -- w relative to CG, X
local headY = globalPropertyf("sim/graphics/view/pilots_head_y")
local headZ = globalPropertyf("sim/graphics/view/pilots_head_z")
local headThe = globalPropertyf("sim/graphics/view/pilots_head_the")            -- w
local autoPower = globalPropertyi("sim/cockpit/autopilot/autopilot_mode")
-- The autopilot master mode (off=0, flight director=1, on=2)
local roll = globalPropertyf("sim/flightmodel2/controls/roll_ratio") 
--  -1.0 is full left, and 1.0 is full right, W
local rollStatus = globalPropertyi("sim/cockpit2/autopilot/roll_status")
--     Autopilot Roll-Hold Status. 0=off,2=captured    RO
local rollDeg = globalPropertyf("sim/cockpit2/autopilot/set_roll_deg")
local altFt = globalPropertyf("sim/cockpit2/gauges/indicators/altitude_ft_pilot")
local gearOnGround = globalPropertyia("sim/flightmodel2/gear/on_ground")

cycle1 = 0
cycle2 = 0
cycle3 = 0
cycle4 = 0
-- set(autoPower, 0)
roll_ratio = { }
for i = 1, 10 do -- 操縦桿ピッチ履歴を全て0(中立)に設定
	roll_ratio [i] = 0
end

-- Control functions  ------------------------------------------
function update()
	-- Mean roll value of latest 10 samples --------------------
	mean_roll = get ( roll )                          -- 最初の操縦桿ロール値取得
	for i = 2, 10 do
		mean_roll = mean_roll + roll_ratio [ i ]
		roll_ratio [ i - 1 ] = roll_ratio [ i ]
	end
	roll_ratio [ 10 ] = get ( roll )
	mean_roll = mean_roll / 10                        -- 操縦桿ロールの10 回平均取得
	
	-- Set wing leveler by height and stick operation  ---------------- 
	if get(altFt)>100 then                            -- 高度100ft以下で
		if math.abs(mean_roll)<0.1 then               -- 操縦桿左右中立の時Wing leveler起動
			if cycle2 == 0 then
-- 				set(autoPower, 2)
				sasl.commandOnce( rollHold )
				set(rollDeg, 0.0)
-- 				print("rollStatus:", get(rollStatus))
				cycle2 = 1
				cycle3 = 0
			end
		elseif math.abs(mean_roll)>0.1 then           -- 操縦桿左右中立以外の時Wing leveler停止
			if cycle3 == 0 then
				sasl.commandOnce( rollHold )
-- 				set(autoPower, 0)
-- 				print("rollStatus:", get(rollStatus))
				cycle2 = 0
				cycle3 = 1
			end
		end
	end

	-- Set pilot's eye position at first only  --------------------------
	if cycle1 == 0 then
		set(headX, 0.0)
		set(headY, 1.8)
		set(headZ, 1.46)
		set(headThe, -8.0)
		seatPos = 0                   -- 0:Pilot, 1:Radio operator, 2:Gunner  
		cycle1 = 1
	end
	
	-- Set gear up if it is not ground
	if cycle4 == 0 then
		if get(gearOnGround, 1) ~= 1 then
			sasl.commandOnce( gearUp )
			cycle4 = 1
		end
	end
end

function keyHandler(c,Code,shiftDown,ctrlDown,altOptDown,KB_DOWN_EVENT)
	if Code == SASL_VK_NUMPAD0 then                  -- Pilot seat is set
		set(headY, 1.8)
		set(headZ, 1.46)
		set(headThe, -8.0)
		seatPos = 0
	end
	
	if Code == SASL_VK_NUMPAD1 then                  -- Radio operator seat is set
		set(headX, 0.0)
		set(headY, 1.6)
		set(headZ, 2.44)
		set(headThe, -10.7)
		seatPos = 1
	end
	
	if Code == SASL_VK_NUMPAD2 then                  -- Gunner seat is set
		set(headX, 0.0)
		set(headY, 1.6)
		set(headZ, 2.0)
		set(headThe, -7.0)
		seatPos = 2
	end
end
sasl.registerGlobalKeyHandler ( keyHandler )